function [peaksHe,peaksPpm] = BOP_extractPeaks(data,ppm,topn,verbose)
% [peaksHe,peaksPpm] = BOP_extractPeaks(data,ppm,topn,verbose)
% 
% Bag of Peaks: extract ntop peaks from the traces
%
% data: D x L matrix (traces are per row), containing D traces each long L points
% ppm: 1 x L vector, containing location
% topn: number of peaks to retain from every trace
% verbose: display some information
%
% peaksHe: D x topn matrix: heights of topn peaks
% peaksPpm: D x topn matrix: location of topn peaks
%
% NOTE: peaks are simply extracted with the findpeaks function of Matlab
% More clever strategies can be used


nel = size(data,1);
peaksHe = zeros(nel,topn);
peaksPpm = zeros(nel,topn);
for i = 1:nel
    trace = data(i,:);
    [pks,locs] = findpeaks(trace);
    [sortP,sortNdx] = sort(pks,'descend');
    peaksHe(i,:) = sortP(1:topn);
    peaksPpm(i,:) = ppm(locs(sortNdx(1:topn)));
    if verbose, figure(1)
        fprintf('Extracting peaks %d\n',i);
        plot(ppm,trace), hold on
        plot(peaksPpm(i,:),peaksHe(i,:),'ro')
        hold off
        pause(0.5)
    end
end
           