% code for Bag of Peaks
% G. Brelstaff, M. Bicego, N. Culeddu, M. Chessa: 
% "Bag of Peaks: interpretation of NMR spectrometry", 
% Bioinformatics, vol. 25, pp 258-264, (2009)
%
% (C) Manuele Bicego (manuele.bicego@univr.it) (2015)
% example of usage



clear all
close all

% verbose = 1 --> display some information
verbose = 0;
% topn: number of peaks to retain from every trace
topn = 20; 
% DictSize: desired size of dictionary. if DictSize == -1, 
%     then the size is automatically estimated via the Davies Bouldin index
DictSize = 10; 
% DictRange: vector containing the possible dictionary size
%     (to be investigated in the automatic search)
DictRange = 5:2:50; 

% Dataset.
% put in matrix "data" and "ppm" your traces as follows
% data: D x L matrix (traces are per row), containing D traces each long L
%       points
% ppm: 1 x L vector, containing locations

% Extracting all peaks from all traces
[peaksHe,peaksPpm] = BOP_extractPeaks(data,ppm,topn,verbose);

% Building Dictionary with 10 entries
peakDict = BOP_buildingDictionary(peaksPpm,DictSize,DictRange,verbose);
% Alternative: automatic size dictionary
peakDict = BOP_buildingDictionary(peaksPpm,-1,DictRange,verbose);

% Extract BOP Representation: if traces used to build the dictionary
% are different from those to be represented, use again BOP_extractPeaks
BOP = BOP_representation(peaksHe, peaksPpm, peakDict);

