function BOP = BOP_representation(peaksHe, peaksPpm, peakDict)
% BOP = BOP_representation(peaksHe, peaksPpm, peakDict)
% 
% BOP derive the Bag of Peaks representation
%
% peaksHe: D x topn matrix: heights of topn peaks to be represented
% peaksPpm: D x topn matrix: location of topn peaks to be represented
% peakDict: vector nPx1 containing the location of the nP peaks of the Dictionary
% 
% BOP: DxnP matrix containing the Bag of Peaks representation
% 

[nel,topn] = size(peaksHe);
nWDict = length(peakDict);
BOP = zeros(nel,nWDict);
for i = 1:nel
    p = peaksPpm(i,:);
    d = abs(repmat(peakDict,[1,topn])-repmat(p,[nWDict,1]));
    [~,pd] = min(d);
    h = peaksHe(i,:);
    h = h./max(h); %normalization: dividing by highest peak
    xBP = zeros(1,nWDict);
    for j = 1:nWDict
        xBP(j) = sum(h(pd==j));
    end
    BOP(i,:) = xBP;
end